runsnapshot

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the runsnapshot type in the database.
	Label = "run_snapshot"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldRunID holds the string denoting the run_id field in the database.
	FieldRunID = "run_id"
	// FieldSessionKey holds the string denoting the session_key field in the database.
	FieldSessionKey = "session_key"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldGoal holds the string denoting the goal field in the database.
	FieldGoal = "goal"
	// FieldSnapshotData holds the string denoting the snapshot_data field in the database.
	FieldSnapshotData = "snapshot_data"
	// FieldLastJournalSeq holds the string denoting the last_journal_seq field in the database.
	FieldLastJournalSeq = "last_journal_seq"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// Table holds the table name of the runsnapshot in the database.
	Table = "run_snapshots"
)
const DefaultStatus = StatusPlanning

StatusPlanning is the default value of the Status enum.

Variables

var (
	// RunIDValidator is a validator for the "run_id" field. It is called by the builders before save.
	RunIDValidator func(string) error
	// DefaultLastJournalSeq holds the default value on creation for the "last_journal_seq" field.
	DefaultLastJournalSeq int64
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for runsnapshot fields.

Functions

func And

func And(predicates ...predicate.RunSnapshot) predicate.RunSnapshot

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.RunSnapshot

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.RunSnapshot

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.RunSnapshot

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.RunSnapshot

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.RunSnapshot

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.RunSnapshot

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.RunSnapshot

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.RunSnapshot

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.RunSnapshot

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Goal

Goal applies equality check predicate on the "goal" field. It's identical to GoalEQ.

func GoalContains

func GoalContains(v string) predicate.RunSnapshot

GoalContains applies the Contains predicate on the "goal" field.

func GoalContainsFold

func GoalContainsFold(v string) predicate.RunSnapshot

GoalContainsFold applies the ContainsFold predicate on the "goal" field.

func GoalEQ

func GoalEQ(v string) predicate.RunSnapshot

GoalEQ applies the EQ predicate on the "goal" field.

func GoalEqualFold

func GoalEqualFold(v string) predicate.RunSnapshot

GoalEqualFold applies the EqualFold predicate on the "goal" field.

func GoalGT

func GoalGT(v string) predicate.RunSnapshot

GoalGT applies the GT predicate on the "goal" field.

func GoalGTE

func GoalGTE(v string) predicate.RunSnapshot

GoalGTE applies the GTE predicate on the "goal" field.

func GoalHasPrefix

func GoalHasPrefix(v string) predicate.RunSnapshot

GoalHasPrefix applies the HasPrefix predicate on the "goal" field.

func GoalHasSuffix

func GoalHasSuffix(v string) predicate.RunSnapshot

GoalHasSuffix applies the HasSuffix predicate on the "goal" field.

func GoalIn

func GoalIn(vs ...string) predicate.RunSnapshot

GoalIn applies the In predicate on the "goal" field.

func GoalIsNil

func GoalIsNil() predicate.RunSnapshot

GoalIsNil applies the IsNil predicate on the "goal" field.

func GoalLT

func GoalLT(v string) predicate.RunSnapshot

GoalLT applies the LT predicate on the "goal" field.

func GoalLTE

func GoalLTE(v string) predicate.RunSnapshot

GoalLTE applies the LTE predicate on the "goal" field.

func GoalNEQ

func GoalNEQ(v string) predicate.RunSnapshot

GoalNEQ applies the NEQ predicate on the "goal" field.

func GoalNotIn

func GoalNotIn(vs ...string) predicate.RunSnapshot

GoalNotIn applies the NotIn predicate on the "goal" field.

func GoalNotNil

func GoalNotNil() predicate.RunSnapshot

GoalNotNil applies the NotNil predicate on the "goal" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.RunSnapshot

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.RunSnapshot

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.RunSnapshot

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.RunSnapshot

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.RunSnapshot

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.RunSnapshot

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.RunSnapshot

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.RunSnapshot

IDNotIn applies the NotIn predicate on the ID field.

func LastJournalSeq

func LastJournalSeq(v int64) predicate.RunSnapshot

LastJournalSeq applies equality check predicate on the "last_journal_seq" field. It's identical to LastJournalSeqEQ.

func LastJournalSeqEQ

func LastJournalSeqEQ(v int64) predicate.RunSnapshot

LastJournalSeqEQ applies the EQ predicate on the "last_journal_seq" field.

func LastJournalSeqGT

func LastJournalSeqGT(v int64) predicate.RunSnapshot

LastJournalSeqGT applies the GT predicate on the "last_journal_seq" field.

func LastJournalSeqGTE

func LastJournalSeqGTE(v int64) predicate.RunSnapshot

LastJournalSeqGTE applies the GTE predicate on the "last_journal_seq" field.

func LastJournalSeqIn

func LastJournalSeqIn(vs ...int64) predicate.RunSnapshot

LastJournalSeqIn applies the In predicate on the "last_journal_seq" field.

func LastJournalSeqLT

func LastJournalSeqLT(v int64) predicate.RunSnapshot

LastJournalSeqLT applies the LT predicate on the "last_journal_seq" field.

func LastJournalSeqLTE

func LastJournalSeqLTE(v int64) predicate.RunSnapshot

LastJournalSeqLTE applies the LTE predicate on the "last_journal_seq" field.

func LastJournalSeqNEQ

func LastJournalSeqNEQ(v int64) predicate.RunSnapshot

LastJournalSeqNEQ applies the NEQ predicate on the "last_journal_seq" field.

func LastJournalSeqNotIn

func LastJournalSeqNotIn(vs ...int64) predicate.RunSnapshot

LastJournalSeqNotIn applies the NotIn predicate on the "last_journal_seq" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.RunSnapshot) predicate.RunSnapshot

Or groups predicates with the OR operator between them.

func RunID

func RunID(v string) predicate.RunSnapshot

RunID applies equality check predicate on the "run_id" field. It's identical to RunIDEQ.

func RunIDContains

func RunIDContains(v string) predicate.RunSnapshot

RunIDContains applies the Contains predicate on the "run_id" field.

func RunIDContainsFold

func RunIDContainsFold(v string) predicate.RunSnapshot

RunIDContainsFold applies the ContainsFold predicate on the "run_id" field.

func RunIDEQ

func RunIDEQ(v string) predicate.RunSnapshot

RunIDEQ applies the EQ predicate on the "run_id" field.

func RunIDEqualFold

func RunIDEqualFold(v string) predicate.RunSnapshot

RunIDEqualFold applies the EqualFold predicate on the "run_id" field.

func RunIDGT

func RunIDGT(v string) predicate.RunSnapshot

RunIDGT applies the GT predicate on the "run_id" field.

func RunIDGTE

func RunIDGTE(v string) predicate.RunSnapshot

RunIDGTE applies the GTE predicate on the "run_id" field.

func RunIDHasPrefix

func RunIDHasPrefix(v string) predicate.RunSnapshot

RunIDHasPrefix applies the HasPrefix predicate on the "run_id" field.

func RunIDHasSuffix

func RunIDHasSuffix(v string) predicate.RunSnapshot

RunIDHasSuffix applies the HasSuffix predicate on the "run_id" field.

func RunIDIn

func RunIDIn(vs ...string) predicate.RunSnapshot

RunIDIn applies the In predicate on the "run_id" field.

func RunIDLT

func RunIDLT(v string) predicate.RunSnapshot

RunIDLT applies the LT predicate on the "run_id" field.

func RunIDLTE

func RunIDLTE(v string) predicate.RunSnapshot

RunIDLTE applies the LTE predicate on the "run_id" field.

func RunIDNEQ

func RunIDNEQ(v string) predicate.RunSnapshot

RunIDNEQ applies the NEQ predicate on the "run_id" field.

func RunIDNotIn

func RunIDNotIn(vs ...string) predicate.RunSnapshot

RunIDNotIn applies the NotIn predicate on the "run_id" field.

func SessionKey

func SessionKey(v string) predicate.RunSnapshot

SessionKey applies equality check predicate on the "session_key" field. It's identical to SessionKeyEQ.

func SessionKeyContains

func SessionKeyContains(v string) predicate.RunSnapshot

SessionKeyContains applies the Contains predicate on the "session_key" field.

func SessionKeyContainsFold

func SessionKeyContainsFold(v string) predicate.RunSnapshot

SessionKeyContainsFold applies the ContainsFold predicate on the "session_key" field.

func SessionKeyEQ

func SessionKeyEQ(v string) predicate.RunSnapshot

SessionKeyEQ applies the EQ predicate on the "session_key" field.

func SessionKeyEqualFold

func SessionKeyEqualFold(v string) predicate.RunSnapshot

SessionKeyEqualFold applies the EqualFold predicate on the "session_key" field.

func SessionKeyGT

func SessionKeyGT(v string) predicate.RunSnapshot

SessionKeyGT applies the GT predicate on the "session_key" field.

func SessionKeyGTE

func SessionKeyGTE(v string) predicate.RunSnapshot

SessionKeyGTE applies the GTE predicate on the "session_key" field.

func SessionKeyHasPrefix

func SessionKeyHasPrefix(v string) predicate.RunSnapshot

SessionKeyHasPrefix applies the HasPrefix predicate on the "session_key" field.

func SessionKeyHasSuffix

func SessionKeyHasSuffix(v string) predicate.RunSnapshot

SessionKeyHasSuffix applies the HasSuffix predicate on the "session_key" field.

func SessionKeyIn

func SessionKeyIn(vs ...string) predicate.RunSnapshot

SessionKeyIn applies the In predicate on the "session_key" field.

func SessionKeyIsNil

func SessionKeyIsNil() predicate.RunSnapshot

SessionKeyIsNil applies the IsNil predicate on the "session_key" field.

func SessionKeyLT

func SessionKeyLT(v string) predicate.RunSnapshot

SessionKeyLT applies the LT predicate on the "session_key" field.

func SessionKeyLTE

func SessionKeyLTE(v string) predicate.RunSnapshot

SessionKeyLTE applies the LTE predicate on the "session_key" field.

func SessionKeyNEQ

func SessionKeyNEQ(v string) predicate.RunSnapshot

SessionKeyNEQ applies the NEQ predicate on the "session_key" field.

func SessionKeyNotIn

func SessionKeyNotIn(vs ...string) predicate.RunSnapshot

SessionKeyNotIn applies the NotIn predicate on the "session_key" field.

func SessionKeyNotNil

func SessionKeyNotNil() predicate.RunSnapshot

SessionKeyNotNil applies the NotNil predicate on the "session_key" field.

func SnapshotData

func SnapshotData(v string) predicate.RunSnapshot

SnapshotData applies equality check predicate on the "snapshot_data" field. It's identical to SnapshotDataEQ.

func SnapshotDataContains

func SnapshotDataContains(v string) predicate.RunSnapshot

SnapshotDataContains applies the Contains predicate on the "snapshot_data" field.

func SnapshotDataContainsFold

func SnapshotDataContainsFold(v string) predicate.RunSnapshot

SnapshotDataContainsFold applies the ContainsFold predicate on the "snapshot_data" field.

func SnapshotDataEQ

func SnapshotDataEQ(v string) predicate.RunSnapshot

SnapshotDataEQ applies the EQ predicate on the "snapshot_data" field.

func SnapshotDataEqualFold

func SnapshotDataEqualFold(v string) predicate.RunSnapshot

SnapshotDataEqualFold applies the EqualFold predicate on the "snapshot_data" field.

func SnapshotDataGT

func SnapshotDataGT(v string) predicate.RunSnapshot

SnapshotDataGT applies the GT predicate on the "snapshot_data" field.

func SnapshotDataGTE

func SnapshotDataGTE(v string) predicate.RunSnapshot

SnapshotDataGTE applies the GTE predicate on the "snapshot_data" field.

func SnapshotDataHasPrefix

func SnapshotDataHasPrefix(v string) predicate.RunSnapshot

SnapshotDataHasPrefix applies the HasPrefix predicate on the "snapshot_data" field.

func SnapshotDataHasSuffix

func SnapshotDataHasSuffix(v string) predicate.RunSnapshot

SnapshotDataHasSuffix applies the HasSuffix predicate on the "snapshot_data" field.

func SnapshotDataIn

func SnapshotDataIn(vs ...string) predicate.RunSnapshot

SnapshotDataIn applies the In predicate on the "snapshot_data" field.

func SnapshotDataLT

func SnapshotDataLT(v string) predicate.RunSnapshot

SnapshotDataLT applies the LT predicate on the "snapshot_data" field.

func SnapshotDataLTE

func SnapshotDataLTE(v string) predicate.RunSnapshot

SnapshotDataLTE applies the LTE predicate on the "snapshot_data" field.

func SnapshotDataNEQ

func SnapshotDataNEQ(v string) predicate.RunSnapshot

SnapshotDataNEQ applies the NEQ predicate on the "snapshot_data" field.

func SnapshotDataNotIn

func SnapshotDataNotIn(vs ...string) predicate.RunSnapshot

SnapshotDataNotIn applies the NotIn predicate on the "snapshot_data" field.

func StatusEQ

func StatusEQ(v Status) predicate.RunSnapshot

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...Status) predicate.RunSnapshot

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v Status) predicate.RunSnapshot

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...Status) predicate.RunSnapshot

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s Status) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.RunSnapshot

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.RunSnapshot

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.RunSnapshot

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.RunSnapshot

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.RunSnapshot

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.RunSnapshot

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.RunSnapshot

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.RunSnapshot

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.RunSnapshot

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the RunSnapshot queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByGoal

func ByGoal(opts ...sql.OrderTermOption) OrderOption

ByGoal orders the results by the goal field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLastJournalSeq

func ByLastJournalSeq(opts ...sql.OrderTermOption) OrderOption

ByLastJournalSeq orders the results by the last_journal_seq field.

func ByRunID

func ByRunID(opts ...sql.OrderTermOption) OrderOption

ByRunID orders the results by the run_id field.

func BySessionKey

func BySessionKey(opts ...sql.OrderTermOption) OrderOption

BySessionKey orders the results by the session_key field.

func BySnapshotData

func BySnapshotData(opts ...sql.OrderTermOption) OrderOption

BySnapshotData orders the results by the snapshot_data field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

type Status

type Status string

Status defines the type for the "status" enum field.

const (
	StatusPlanning  Status = "planning"
	StatusRunning   Status = "running"
	StatusPaused    Status = "paused"
	StatusCompleted Status = "completed"
	StatusFailed    Status = "failed"
)

Status values.

func (Status) String

func (s Status) String() string

Jump to