Documentation
¶
Index ¶
- Constants
- Variables
- func Active(v bool) predicate.ConfigProfile
- func ActiveEQ(v bool) predicate.ConfigProfile
- func ActiveNEQ(v bool) predicate.ConfigProfile
- func And(predicates ...predicate.ConfigProfile) predicate.ConfigProfile
- func CreatedAt(v time.Time) predicate.ConfigProfile
- func CreatedAtEQ(v time.Time) predicate.ConfigProfile
- func CreatedAtGT(v time.Time) predicate.ConfigProfile
- func CreatedAtGTE(v time.Time) predicate.ConfigProfile
- func CreatedAtIn(vs ...time.Time) predicate.ConfigProfile
- func CreatedAtLT(v time.Time) predicate.ConfigProfile
- func CreatedAtLTE(v time.Time) predicate.ConfigProfile
- func CreatedAtNEQ(v time.Time) predicate.ConfigProfile
- func CreatedAtNotIn(vs ...time.Time) predicate.ConfigProfile
- func EncryptedData(v []byte) predicate.ConfigProfile
- func EncryptedDataEQ(v []byte) predicate.ConfigProfile
- func EncryptedDataGT(v []byte) predicate.ConfigProfile
- func EncryptedDataGTE(v []byte) predicate.ConfigProfile
- func EncryptedDataIn(vs ...[]byte) predicate.ConfigProfile
- func EncryptedDataLT(v []byte) predicate.ConfigProfile
- func EncryptedDataLTE(v []byte) predicate.ConfigProfile
- func EncryptedDataNEQ(v []byte) predicate.ConfigProfile
- func EncryptedDataNotIn(vs ...[]byte) predicate.ConfigProfile
- func ID(id uuid.UUID) predicate.ConfigProfile
- func IDEQ(id uuid.UUID) predicate.ConfigProfile
- func IDGT(id uuid.UUID) predicate.ConfigProfile
- func IDGTE(id uuid.UUID) predicate.ConfigProfile
- func IDIn(ids ...uuid.UUID) predicate.ConfigProfile
- func IDLT(id uuid.UUID) predicate.ConfigProfile
- func IDLTE(id uuid.UUID) predicate.ConfigProfile
- func IDNEQ(id uuid.UUID) predicate.ConfigProfile
- func IDNotIn(ids ...uuid.UUID) predicate.ConfigProfile
- func Name(v string) predicate.ConfigProfile
- func NameContains(v string) predicate.ConfigProfile
- func NameContainsFold(v string) predicate.ConfigProfile
- func NameEQ(v string) predicate.ConfigProfile
- func NameEqualFold(v string) predicate.ConfigProfile
- func NameGT(v string) predicate.ConfigProfile
- func NameGTE(v string) predicate.ConfigProfile
- func NameHasPrefix(v string) predicate.ConfigProfile
- func NameHasSuffix(v string) predicate.ConfigProfile
- func NameIn(vs ...string) predicate.ConfigProfile
- func NameLT(v string) predicate.ConfigProfile
- func NameLTE(v string) predicate.ConfigProfile
- func NameNEQ(v string) predicate.ConfigProfile
- func NameNotIn(vs ...string) predicate.ConfigProfile
- func Not(p predicate.ConfigProfile) predicate.ConfigProfile
- func Or(predicates ...predicate.ConfigProfile) predicate.ConfigProfile
- func UpdatedAt(v time.Time) predicate.ConfigProfile
- func UpdatedAtEQ(v time.Time) predicate.ConfigProfile
- func UpdatedAtGT(v time.Time) predicate.ConfigProfile
- func UpdatedAtGTE(v time.Time) predicate.ConfigProfile
- func UpdatedAtIn(vs ...time.Time) predicate.ConfigProfile
- func UpdatedAtLT(v time.Time) predicate.ConfigProfile
- func UpdatedAtLTE(v time.Time) predicate.ConfigProfile
- func UpdatedAtNEQ(v time.Time) predicate.ConfigProfile
- func UpdatedAtNotIn(vs ...time.Time) predicate.ConfigProfile
- func ValidColumn(column string) bool
- func Version(v int) predicate.ConfigProfile
- func VersionEQ(v int) predicate.ConfigProfile
- func VersionGT(v int) predicate.ConfigProfile
- func VersionGTE(v int) predicate.ConfigProfile
- func VersionIn(vs ...int) predicate.ConfigProfile
- func VersionLT(v int) predicate.ConfigProfile
- func VersionLTE(v int) predicate.ConfigProfile
- func VersionNEQ(v int) predicate.ConfigProfile
- func VersionNotIn(vs ...int) predicate.ConfigProfile
- type OrderOption
- func ByActive(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByVersion(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the configprofile type in the database. Label = "config_profile" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldEncryptedData holds the string denoting the encrypted_data field in the database. FieldEncryptedData = "encrypted_data" // FieldActive holds the string denoting the active field in the database. FieldActive = "active" // FieldVersion holds the string denoting the version field in the database. FieldVersion = "version" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the configprofile in the database. Table = "config_profiles" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultActive holds the default value on creation for the "active" field. DefaultActive bool // DefaultVersion holds the default value on creation for the "version" field. DefaultVersion int // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldName, FieldEncryptedData, FieldActive, FieldVersion, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for configprofile fields.
Functions ¶
func Active ¶
func Active(v bool) predicate.ConfigProfile
Active applies equality check predicate on the "active" field. It's identical to ActiveEQ.
func ActiveEQ ¶
func ActiveEQ(v bool) predicate.ConfigProfile
ActiveEQ applies the EQ predicate on the "active" field.
func ActiveNEQ ¶
func ActiveNEQ(v bool) predicate.ConfigProfile
ActiveNEQ applies the NEQ predicate on the "active" field.
func And ¶
func And(predicates ...predicate.ConfigProfile) predicate.ConfigProfile
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.ConfigProfile
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.ConfigProfile
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.ConfigProfile
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.ConfigProfile
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.ConfigProfile
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.ConfigProfile
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.ConfigProfile
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.ConfigProfile
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.ConfigProfile
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func EncryptedData ¶
func EncryptedData(v []byte) predicate.ConfigProfile
EncryptedData applies equality check predicate on the "encrypted_data" field. It's identical to EncryptedDataEQ.
func EncryptedDataEQ ¶
func EncryptedDataEQ(v []byte) predicate.ConfigProfile
EncryptedDataEQ applies the EQ predicate on the "encrypted_data" field.
func EncryptedDataGT ¶
func EncryptedDataGT(v []byte) predicate.ConfigProfile
EncryptedDataGT applies the GT predicate on the "encrypted_data" field.
func EncryptedDataGTE ¶
func EncryptedDataGTE(v []byte) predicate.ConfigProfile
EncryptedDataGTE applies the GTE predicate on the "encrypted_data" field.
func EncryptedDataIn ¶
func EncryptedDataIn(vs ...[]byte) predicate.ConfigProfile
EncryptedDataIn applies the In predicate on the "encrypted_data" field.
func EncryptedDataLT ¶
func EncryptedDataLT(v []byte) predicate.ConfigProfile
EncryptedDataLT applies the LT predicate on the "encrypted_data" field.
func EncryptedDataLTE ¶
func EncryptedDataLTE(v []byte) predicate.ConfigProfile
EncryptedDataLTE applies the LTE predicate on the "encrypted_data" field.
func EncryptedDataNEQ ¶
func EncryptedDataNEQ(v []byte) predicate.ConfigProfile
EncryptedDataNEQ applies the NEQ predicate on the "encrypted_data" field.
func EncryptedDataNotIn ¶
func EncryptedDataNotIn(vs ...[]byte) predicate.ConfigProfile
EncryptedDataNotIn applies the NotIn predicate on the "encrypted_data" field.
func ID ¶
func ID(id uuid.UUID) predicate.ConfigProfile
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.ConfigProfile
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.ConfigProfile
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.ConfigProfile
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.ConfigProfile
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.ConfigProfile
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.ConfigProfile
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.ConfigProfile
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.ConfigProfile
IDNotIn applies the NotIn predicate on the ID field.
func Name ¶
func Name(v string) predicate.ConfigProfile
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.ConfigProfile
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.ConfigProfile
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.ConfigProfile
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.ConfigProfile
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.ConfigProfile
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.ConfigProfile
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.ConfigProfile
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.ConfigProfile
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.ConfigProfile
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.ConfigProfile
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.ConfigProfile
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.ConfigProfile
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.ConfigProfile
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.ConfigProfile) predicate.ConfigProfile
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.ConfigProfile) predicate.ConfigProfile
Or groups predicates with the OR operator between them.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.ConfigProfile
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.ConfigProfile
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.ConfigProfile
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.ConfigProfile
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.ConfigProfile
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.ConfigProfile
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.ConfigProfile
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.ConfigProfile
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.ConfigProfile
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Version ¶
func Version(v int) predicate.ConfigProfile
Version applies equality check predicate on the "version" field. It's identical to VersionEQ.
func VersionEQ ¶
func VersionEQ(v int) predicate.ConfigProfile
VersionEQ applies the EQ predicate on the "version" field.
func VersionGT ¶
func VersionGT(v int) predicate.ConfigProfile
VersionGT applies the GT predicate on the "version" field.
func VersionGTE ¶
func VersionGTE(v int) predicate.ConfigProfile
VersionGTE applies the GTE predicate on the "version" field.
func VersionIn ¶
func VersionIn(vs ...int) predicate.ConfigProfile
VersionIn applies the In predicate on the "version" field.
func VersionLT ¶
func VersionLT(v int) predicate.ConfigProfile
VersionLT applies the LT predicate on the "version" field.
func VersionLTE ¶
func VersionLTE(v int) predicate.ConfigProfile
VersionLTE applies the LTE predicate on the "version" field.
func VersionNEQ ¶
func VersionNEQ(v int) predicate.ConfigProfile
VersionNEQ applies the NEQ predicate on the "version" field.
func VersionNotIn ¶
func VersionNotIn(vs ...int) predicate.ConfigProfile
VersionNotIn applies the NotIn predicate on the "version" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ConfigProfile queries.
func ByActive ¶
func ByActive(opts ...sql.OrderTermOption) OrderOption
ByActive orders the results by the active field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByVersion ¶
func ByVersion(opts ...sql.OrderTermOption) OrderOption
ByVersion orders the results by the version field.