Documentation
¶
Index ¶
- Constants
- Variables
- func AgentID(v string) predicate.Session
- func AgentIDContains(v string) predicate.Session
- func AgentIDContainsFold(v string) predicate.Session
- func AgentIDEQ(v string) predicate.Session
- func AgentIDEqualFold(v string) predicate.Session
- func AgentIDGT(v string) predicate.Session
- func AgentIDGTE(v string) predicate.Session
- func AgentIDHasPrefix(v string) predicate.Session
- func AgentIDHasSuffix(v string) predicate.Session
- func AgentIDIn(vs ...string) predicate.Session
- func AgentIDIsNil() predicate.Session
- func AgentIDLT(v string) predicate.Session
- func AgentIDLTE(v string) predicate.Session
- func AgentIDNEQ(v string) predicate.Session
- func AgentIDNotIn(vs ...string) predicate.Session
- func AgentIDNotNil() predicate.Session
- func And(predicates ...predicate.Session) predicate.Session
- func ChannelID(v string) predicate.Session
- func ChannelIDContains(v string) predicate.Session
- func ChannelIDContainsFold(v string) predicate.Session
- func ChannelIDEQ(v string) predicate.Session
- func ChannelIDEqualFold(v string) predicate.Session
- func ChannelIDGT(v string) predicate.Session
- func ChannelIDGTE(v string) predicate.Session
- func ChannelIDHasPrefix(v string) predicate.Session
- func ChannelIDHasSuffix(v string) predicate.Session
- func ChannelIDIn(vs ...string) predicate.Session
- func ChannelIDIsNil() predicate.Session
- func ChannelIDLT(v string) predicate.Session
- func ChannelIDLTE(v string) predicate.Session
- func ChannelIDNEQ(v string) predicate.Session
- func ChannelIDNotIn(vs ...string) predicate.Session
- func ChannelIDNotNil() predicate.Session
- func ChannelType(v string) predicate.Session
- func ChannelTypeContains(v string) predicate.Session
- func ChannelTypeContainsFold(v string) predicate.Session
- func ChannelTypeEQ(v string) predicate.Session
- func ChannelTypeEqualFold(v string) predicate.Session
- func ChannelTypeGT(v string) predicate.Session
- func ChannelTypeGTE(v string) predicate.Session
- func ChannelTypeHasPrefix(v string) predicate.Session
- func ChannelTypeHasSuffix(v string) predicate.Session
- func ChannelTypeIn(vs ...string) predicate.Session
- func ChannelTypeIsNil() predicate.Session
- func ChannelTypeLT(v string) predicate.Session
- func ChannelTypeLTE(v string) predicate.Session
- func ChannelTypeNEQ(v string) predicate.Session
- func ChannelTypeNotIn(vs ...string) predicate.Session
- func ChannelTypeNotNil() predicate.Session
- func CreatedAt(v time.Time) predicate.Session
- func CreatedAtEQ(v time.Time) predicate.Session
- func CreatedAtGT(v time.Time) predicate.Session
- func CreatedAtGTE(v time.Time) predicate.Session
- func CreatedAtIn(vs ...time.Time) predicate.Session
- func CreatedAtLT(v time.Time) predicate.Session
- func CreatedAtLTE(v time.Time) predicate.Session
- func CreatedAtNEQ(v time.Time) predicate.Session
- func CreatedAtNotIn(vs ...time.Time) predicate.Session
- func HasMessages() predicate.Session
- func HasMessagesWith(preds ...predicate.Message) predicate.Session
- func ID(id int) predicate.Session
- func IDEQ(id int) predicate.Session
- func IDGT(id int) predicate.Session
- func IDGTE(id int) predicate.Session
- func IDIn(ids ...int) predicate.Session
- func IDLT(id int) predicate.Session
- func IDLTE(id int) predicate.Session
- func IDNEQ(id int) predicate.Session
- func IDNotIn(ids ...int) predicate.Session
- func Key(v string) predicate.Session
- func KeyContains(v string) predicate.Session
- func KeyContainsFold(v string) predicate.Session
- func KeyEQ(v string) predicate.Session
- func KeyEqualFold(v string) predicate.Session
- func KeyGT(v string) predicate.Session
- func KeyGTE(v string) predicate.Session
- func KeyHasPrefix(v string) predicate.Session
- func KeyHasSuffix(v string) predicate.Session
- func KeyIn(vs ...string) predicate.Session
- func KeyLT(v string) predicate.Session
- func KeyLTE(v string) predicate.Session
- func KeyNEQ(v string) predicate.Session
- func KeyNotIn(vs ...string) predicate.Session
- func MetadataIsNil() predicate.Session
- func MetadataNotNil() predicate.Session
- func Model(v string) predicate.Session
- func ModelContains(v string) predicate.Session
- func ModelContainsFold(v string) predicate.Session
- func ModelEQ(v string) predicate.Session
- func ModelEqualFold(v string) predicate.Session
- func ModelGT(v string) predicate.Session
- func ModelGTE(v string) predicate.Session
- func ModelHasPrefix(v string) predicate.Session
- func ModelHasSuffix(v string) predicate.Session
- func ModelIn(vs ...string) predicate.Session
- func ModelIsNil() predicate.Session
- func ModelLT(v string) predicate.Session
- func ModelLTE(v string) predicate.Session
- func ModelNEQ(v string) predicate.Session
- func ModelNotIn(vs ...string) predicate.Session
- func ModelNotNil() predicate.Session
- func Not(p predicate.Session) predicate.Session
- func Or(predicates ...predicate.Session) predicate.Session
- func UpdatedAt(v time.Time) predicate.Session
- func UpdatedAtEQ(v time.Time) predicate.Session
- func UpdatedAtGT(v time.Time) predicate.Session
- func UpdatedAtGTE(v time.Time) predicate.Session
- func UpdatedAtIn(vs ...time.Time) predicate.Session
- func UpdatedAtLT(v time.Time) predicate.Session
- func UpdatedAtLTE(v time.Time) predicate.Session
- func UpdatedAtNEQ(v time.Time) predicate.Session
- func UpdatedAtNotIn(vs ...time.Time) predicate.Session
- func ValidColumn(column string) bool
- type OrderOption
- func ByAgentID(opts ...sql.OrderTermOption) OrderOption
- func ByChannelID(opts ...sql.OrderTermOption) OrderOption
- func ByChannelType(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByKey(opts ...sql.OrderTermOption) OrderOption
- func ByMessages(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMessagesCount(opts ...sql.OrderTermOption) OrderOption
- func ByModel(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the session type in the database. Label = "session" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldKey holds the string denoting the key field in the database. FieldKey = "key" // FieldAgentID holds the string denoting the agent_id field in the database. FieldAgentID = "agent_id" // FieldChannelType holds the string denoting the channel_type field in the database. FieldChannelType = "channel_type" // FieldChannelID holds the string denoting the channel_id field in the database. FieldChannelID = "channel_id" // FieldModel holds the string denoting the model field in the database. FieldModel = "model" // FieldMetadata holds the string denoting the metadata field in the database. FieldMetadata = "metadata" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeMessages holds the string denoting the messages edge name in mutations. EdgeMessages = "messages" // Table holds the table name of the session in the database. Table = "sessions" // MessagesTable is the table that holds the messages relation/edge. MessagesTable = "messages" // MessagesInverseTable is the table name for the Message entity. // It exists in this package in order to avoid circular dependency with the "message" package. MessagesInverseTable = "messages" // MessagesColumn is the table column denoting the messages relation/edge. MessagesColumn = "session_messages" )
Variables ¶
var ( // KeyValidator is a validator for the "key" field. It is called by the builders before save. KeyValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldKey, FieldAgentID, FieldChannelType, FieldChannelID, FieldModel, FieldMetadata, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for session fields.
Functions ¶
func AgentID ¶
AgentID applies equality check predicate on the "agent_id" field. It's identical to AgentIDEQ.
func AgentIDContains ¶
AgentIDContains applies the Contains predicate on the "agent_id" field.
func AgentIDContainsFold ¶
AgentIDContainsFold applies the ContainsFold predicate on the "agent_id" field.
func AgentIDEqualFold ¶
AgentIDEqualFold applies the EqualFold predicate on the "agent_id" field.
func AgentIDGTE ¶
AgentIDGTE applies the GTE predicate on the "agent_id" field.
func AgentIDHasPrefix ¶
AgentIDHasPrefix applies the HasPrefix predicate on the "agent_id" field.
func AgentIDHasSuffix ¶
AgentIDHasSuffix applies the HasSuffix predicate on the "agent_id" field.
func AgentIDIsNil ¶
AgentIDIsNil applies the IsNil predicate on the "agent_id" field.
func AgentIDLTE ¶
AgentIDLTE applies the LTE predicate on the "agent_id" field.
func AgentIDNEQ ¶
AgentIDNEQ applies the NEQ predicate on the "agent_id" field.
func AgentIDNotIn ¶
AgentIDNotIn applies the NotIn predicate on the "agent_id" field.
func AgentIDNotNil ¶
AgentIDNotNil applies the NotNil predicate on the "agent_id" field.
func ChannelID ¶
ChannelID applies equality check predicate on the "channel_id" field. It's identical to ChannelIDEQ.
func ChannelIDContains ¶
ChannelIDContains applies the Contains predicate on the "channel_id" field.
func ChannelIDContainsFold ¶
ChannelIDContainsFold applies the ContainsFold predicate on the "channel_id" field.
func ChannelIDEQ ¶
ChannelIDEQ applies the EQ predicate on the "channel_id" field.
func ChannelIDEqualFold ¶
ChannelIDEqualFold applies the EqualFold predicate on the "channel_id" field.
func ChannelIDGT ¶
ChannelIDGT applies the GT predicate on the "channel_id" field.
func ChannelIDGTE ¶
ChannelIDGTE applies the GTE predicate on the "channel_id" field.
func ChannelIDHasPrefix ¶
ChannelIDHasPrefix applies the HasPrefix predicate on the "channel_id" field.
func ChannelIDHasSuffix ¶
ChannelIDHasSuffix applies the HasSuffix predicate on the "channel_id" field.
func ChannelIDIn ¶
ChannelIDIn applies the In predicate on the "channel_id" field.
func ChannelIDIsNil ¶
ChannelIDIsNil applies the IsNil predicate on the "channel_id" field.
func ChannelIDLT ¶
ChannelIDLT applies the LT predicate on the "channel_id" field.
func ChannelIDLTE ¶
ChannelIDLTE applies the LTE predicate on the "channel_id" field.
func ChannelIDNEQ ¶
ChannelIDNEQ applies the NEQ predicate on the "channel_id" field.
func ChannelIDNotIn ¶
ChannelIDNotIn applies the NotIn predicate on the "channel_id" field.
func ChannelIDNotNil ¶
ChannelIDNotNil applies the NotNil predicate on the "channel_id" field.
func ChannelType ¶
ChannelType applies equality check predicate on the "channel_type" field. It's identical to ChannelTypeEQ.
func ChannelTypeContains ¶
ChannelTypeContains applies the Contains predicate on the "channel_type" field.
func ChannelTypeContainsFold ¶
ChannelTypeContainsFold applies the ContainsFold predicate on the "channel_type" field.
func ChannelTypeEQ ¶
ChannelTypeEQ applies the EQ predicate on the "channel_type" field.
func ChannelTypeEqualFold ¶
ChannelTypeEqualFold applies the EqualFold predicate on the "channel_type" field.
func ChannelTypeGT ¶
ChannelTypeGT applies the GT predicate on the "channel_type" field.
func ChannelTypeGTE ¶
ChannelTypeGTE applies the GTE predicate on the "channel_type" field.
func ChannelTypeHasPrefix ¶
ChannelTypeHasPrefix applies the HasPrefix predicate on the "channel_type" field.
func ChannelTypeHasSuffix ¶
ChannelTypeHasSuffix applies the HasSuffix predicate on the "channel_type" field.
func ChannelTypeIn ¶
ChannelTypeIn applies the In predicate on the "channel_type" field.
func ChannelTypeIsNil ¶
ChannelTypeIsNil applies the IsNil predicate on the "channel_type" field.
func ChannelTypeLT ¶
ChannelTypeLT applies the LT predicate on the "channel_type" field.
func ChannelTypeLTE ¶
ChannelTypeLTE applies the LTE predicate on the "channel_type" field.
func ChannelTypeNEQ ¶
ChannelTypeNEQ applies the NEQ predicate on the "channel_type" field.
func ChannelTypeNotIn ¶
ChannelTypeNotIn applies the NotIn predicate on the "channel_type" field.
func ChannelTypeNotNil ¶
ChannelTypeNotNil applies the NotNil predicate on the "channel_type" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasMessages ¶
HasMessages applies the HasEdge predicate on the "messages" edge.
func HasMessagesWith ¶
HasMessagesWith applies the HasEdge predicate on the "messages" edge with a given conditions (other predicates).
func KeyContains ¶
KeyContains applies the Contains predicate on the "key" field.
func KeyContainsFold ¶
KeyContainsFold applies the ContainsFold predicate on the "key" field.
func KeyEqualFold ¶
KeyEqualFold applies the EqualFold predicate on the "key" field.
func KeyHasPrefix ¶
KeyHasPrefix applies the HasPrefix predicate on the "key" field.
func KeyHasSuffix ¶
KeyHasSuffix applies the HasSuffix predicate on the "key" field.
func MetadataIsNil ¶
MetadataIsNil applies the IsNil predicate on the "metadata" field.
func MetadataNotNil ¶
MetadataNotNil applies the NotNil predicate on the "metadata" field.
func Model ¶
Model applies equality check predicate on the "model" field. It's identical to ModelEQ.
func ModelContains ¶
ModelContains applies the Contains predicate on the "model" field.
func ModelContainsFold ¶
ModelContainsFold applies the ContainsFold predicate on the "model" field.
func ModelEqualFold ¶
ModelEqualFold applies the EqualFold predicate on the "model" field.
func ModelHasPrefix ¶
ModelHasPrefix applies the HasPrefix predicate on the "model" field.
func ModelHasSuffix ¶
ModelHasSuffix applies the HasSuffix predicate on the "model" field.
func ModelIsNil ¶
ModelIsNil applies the IsNil predicate on the "model" field.
func ModelNotIn ¶
ModelNotIn applies the NotIn predicate on the "model" field.
func ModelNotNil ¶
ModelNotNil applies the NotNil predicate on the "model" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Session queries.
func ByAgentID ¶
func ByAgentID(opts ...sql.OrderTermOption) OrderOption
ByAgentID orders the results by the agent_id field.
func ByChannelID ¶
func ByChannelID(opts ...sql.OrderTermOption) OrderOption
ByChannelID orders the results by the channel_id field.
func ByChannelType ¶
func ByChannelType(opts ...sql.OrderTermOption) OrderOption
ByChannelType orders the results by the channel_type field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByKey ¶
func ByKey(opts ...sql.OrderTermOption) OrderOption
ByKey orders the results by the key field.
func ByMessages ¶
func ByMessages(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMessages orders the results by messages terms.
func ByMessagesCount ¶
func ByMessagesCount(opts ...sql.OrderTermOption) OrderOption
ByMessagesCount orders the results by messages count.
func ByModel ¶
func ByModel(opts ...sql.OrderTermOption) OrderOption
ByModel orders the results by the model field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.